@@ -7,7 +7,16 @@ form_form <-
   function(object, control, env, ...) {
 
     if (inherits(env$data, "data.frame")) {
-      check_outcome(eval_tidy(env$formula[[2]], env$data), object)
+      check_outcome(eval_tidy(rlang::f_lhs(env$formula), env$data), object)
+
+      encoding_info <-
+        get_encoding(class(object)[1]) %>%
+        dplyr::filter(mode == object$mode, engine == object$engine)
+
+      remove_intercept <- encoding_info %>% dplyr::pull(remove_intercept)
+      if (remove_intercept) {
+        env$data <- env$data[, colnames(env$data) != "(Intercept)", drop = FALSE]
+      }
     }
 
     # prob rewrite this as simple subset/levels
@@ -53,7 +62,7 @@ form_form <-
       )
       elapsed <- list(elapsed = NA_real_)
     }
-    res$preproc <- list(y_var = all.vars(env$formula[[2]]))
+    res$preproc <- list(y_var = all.vars(rlang::f_lhs(env$formula)))
     res$elapsed <- elapsed
     res
   }
@@ -112,7 +121,7 @@ xy_xy <- function(object, env, control, target = "none", ...) {
     elapsed <- list(elapsed = NA_real_)
   }
 
-  if (is.vector(env$y)) {
+  if (is.atomic(env$y)) {
     y_name <- character(0)
   } else {
     y_name <- colnames(env$y)
@@ -149,7 +158,7 @@ form_xy <- function(object, control, env,
     control = control,
     target = target
   )
-  data_obj$y_var <- all.vars(env$formula[[2]])
+  data_obj$y_var <- all.vars(rlang::f_lhs(env$formula))
   data_obj$x <- NULL
   data_obj$y <- NULL
   data_obj$weights <- NULL
@@ -190,7 +199,7 @@ xy_form <- function(object, env, control, ...) {
   if (!is.null(env$y_var)) {
     data_obj$y_var <- env$y_var
   } else {
-    if (is.vector(env$y)) {
+    if (is.atomic(env$y)) {
       data_obj$y_var <- character(0)
     }
 
