@@ -11,9 +11,11 @@
 #' @importFrom dplyr arrange bind_cols bind_rows collect full_join group_by
 #' @importFrom dplyr mutate pull rename select starts_with summarise tally
 #' @importFrom generics tunable varying_args tune_args
+#' @importFrom ggplot2 autoplot
 #' @importFrom glue glue_collapse
+#' @importFrom lifecycle deprecated
 #' @importFrom pillar type_sum
-#' @importFrom purrr as_vector imap imap_lgl map map_chr map_dbl map_df map_dfr
+#' @importFrom purrr as_vector imap imap_lgl map map_chr map_dbl
 #' @importFrom purrr map_lgl %||%
 #' @importFrom rlang abort call2 caller_env current_env enquo enquos eval_tidy
 #' @importFrom rlang expr get_expr is_empty is_missing is_null is_quosure
@@ -27,7 +29,6 @@
 #' @importFrom utils capture.output getFromNamespace globalVariables head
 #' @importFrom utils methods stack
 #' @importFrom vctrs vec_size vec_unique
-#' @importFrom ggplot2 autoplot
 ## usethis namespace: end
 NULL
 
@@ -42,7 +43,8 @@ utils::globalVariables(
     "sub_neighbors", ".pred_class", "x", "y", "predictor_indicators",
     "compute_intercept", "remove_intercept", "estimate", "term",
     "call_info", "component", "component_id", "func", "tunable", "label",
-    "pkg", ".order", "item", "tunable", "has_ext", "id", "weights", "has_wts", "protect"
+    "pkg", ".order", "item", "tunable", "has_ext", "id", "weights", "has_wts",
+    "protect", "weight_time", ".prob_cens", ".weight_cens", "s"
   )
 )
 
